pub async fn create_engine(
config: EngineConfig,
) -> Result<Box<dyn LlmInferenceEngine + Send + Sync>>Expand description
Create an engine with the default configuration and registry
pub async fn create_engine(
config: EngineConfig,
) -> Result<Box<dyn LlmInferenceEngine + Send + Sync>>Create an engine with the default configuration and registry